==> haskell-cryptonite-conduit-0.2.2-112-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-3ADG9rBw9Bp9lfqLKBCkc5
key: cryptonite-conduit-0.2.2-3ADG9rBw9Bp9lfqLKBCkc5
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: 988229f7340156ff3467579805506e31
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-3ADG9rBw9Bp9lfqLKBCkc5
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl
    conduit-extra-1.3.0-36s7bkvQjhlAr3LyAHLUCy
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl=027922e93a267b72b868d4ff5db4d6d0
             conduit-extra-1.3.0-36s7bkvQjhlAr3LyAHLUCy=841ef3dc13ffd1f4ce7f0bc348a42f4f
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-114-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-GPdcYuoSyGVCVX10cvzImL
key: cryptonite-conduit-0.2.2-GPdcYuoSyGVCVX10cvzImL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: 3dcf7814155786ec2b4109af9810daa8
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-GPdcYuoSyGVCVX10cvzImL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    conduit-1.3.0.3-21oVxbuLudTDFRaDyFHkw4
    conduit-extra-1.3.0-IsNBoNLATEi80mj4mxpJy
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-21oVxbuLudTDFRaDyFHkw4=a446a7a16dc9f46b5e22956d60c75c44
             conduit-extra-1.3.0-IsNBoNLATEi80mj4mxpJy=548e65ec504a59b6f79c6f732bd1fe14
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
